# DS20KDB command line interface
This library aims to provide a simplified base for accessing the
construction database.

It is a Python 3-based code meant to be run interactively or to be
integrated in Python scripts.

It uses the [pandas](https://pandas.pydata.org/) framework.
